@@ -56,7 +56,7 @@ G_BEGIN_DECLS
  *
  * Since: 3.20
  */
-#define GTK_SOURCE_MICRO_VERSION (0)
+#define GTK_SOURCE_MICRO_VERSION (2)
 
 
 /**
@@ -74,7 +74,7 @@ G_BEGIN_DECLS
  */
 #define GTK_SOURCE_CHECK_VERSION(major, minor, micro) \
 	(GTK_SOURCE_MAJOR_VERSION > (major) || \
-	(GTK_SOURCE_MAJOR_VERSION == (major) && GTK_SOURCE_MINOR_VERSION > (minor)) || \
+	(GTK_SOURCE_MAJOR_VERSION == (major) && GTK_SOURCE_MINOR_VERSION > ((gint) (minor))) || \
 	(GTK_SOURCE_MAJOR_VERSION == (major) && GTK_SOURCE_MINOR_VERSION == (minor) && \
 	 GTK_SOURCE_MICRO_VERSION >= (micro)))
 
@@ -227,16 +227,9 @@ G_BEGIN_DECLS
 #define GTK_SOURCE_VERSION_4_0 (G_ENCODE_VERSION (4, 0))
 
 /* Define GTK_SOURCE_VERSION_CUR_STABLE */
-/* TODO: remove 3.99 special case once GtkSourceView 4 is released, since it'll
- * be dead code (GTK_SOURCE_MAJOR_VERSION will never be equal to 3 anymore).
- */
 #ifndef __GTK_DOC_IGNORE__
 #  if (GTK_SOURCE_MINOR_VERSION % 2)
-#    if ((GTK_SOURCE_MAJOR_VERSION == 3) && (GTK_SOURCE_MINOR_VERSION == 99))
-#      define GTK_SOURCE_VERSION_CUR_STABLE (G_ENCODE_VERSION (GTK_SOURCE_MAJOR_VERSION + 1, 0))
-#    else
-#      define GTK_SOURCE_VERSION_CUR_STABLE (G_ENCODE_VERSION (GTK_SOURCE_MAJOR_VERSION, GTK_SOURCE_MINOR_VERSION + 1))
-#    endif
+#    define GTK_SOURCE_VERSION_CUR_STABLE (G_ENCODE_VERSION (GTK_SOURCE_MAJOR_VERSION, GTK_SOURCE_MINOR_VERSION + 1))
 #  else
 #    define GTK_SOURCE_VERSION_CUR_STABLE (G_ENCODE_VERSION (GTK_SOURCE_MAJOR_VERSION, GTK_SOURCE_MINOR_VERSION))
 #  endif
